<?php
/**
 * Pimcore
 *
 * This source file is available under two different licenses:
 * - GNU General Public License version 3 (GPLv3)
 * - Pimcore Enterprise License (PEL)
 * Full copyright and license information is available in
 * LICENSE.md which is distributed with this source code.
 *
 * @package    AuditBundle
 *
 * @copyright  Copyright (c) Pimcore GmbH (http://www.pimcore.org)
 * @license    http://www.pimcore.org/license     GPLv3 and PEL
 */

namespace AuditBundle\Model\Asset;

use Pimcore\Logger;
use Pimcore\Model;
use Pimcore\Cache;
use Pimcore\Cache\Runtime;

/**
 * Model class to save the asset audit
 *
 * @method \AuditBundle\Model\Asset\AssetAudit\Dao getDao()
 */
class AssetAudit extends Model\AbstractModel
{
    /**
     * @var int
     */
    public $id;

    /**
     * @var int
     */
    public $assetId;

    /**
     * @var string
     */
    public $assetName;

    /**
     * @var string
     */
    public $assetPath;

    /**
     * @var int
     */
    public $userId;

    /**
     * @var string
     */
    public $action;

    /**
     * @var string
     */
    public $actionAt;

    /**
     * Function to get Asset audit by id.
     *
     * @param int $id
     *
     * @return AssetAudit
     */
    public static function getById($id)
    {
        $cacheKey = 'asset_audit_'.$id;

        try {
            $assetAuditUser = Runtime::get($cacheKey);
            if (!$assetAuditUser) {
                throw new \Exception(UtilsHelper::translate('auditB_model_asset_registery_null'));
            }
        } catch (\Exception $e) {
            try {
                $assetAuditUser = new self();
                Runtime::set($cacheKey, $assetAuditUser);
                $assetAuditUser->setId(intval($id));
                $assetAuditUser->getDao()->getById();
            } catch (\Exception $e) {
                Logger::error($e);
                return null;
            }
        }

        return $assetAuditUser;
    }

    /**
     * Function to create Asset Audit.
     *
     * @return AssetAudit
     */
    public static function create()
    {
        $assetAudit = new self();
        $assetAudit->save();

        return $assetAudit;
    }

    /**
     * Function to clear dependent cache.
     */
    public function clearDependentCache()
    {

        // this is mostly called in AssetAudti\Dao not here
        try {
            Cache::clearTag('asset_audit');
        } catch (\Exception $e) {
            Logger::crit($e);
        }
    }
    /**
     * Getter function for id
     *
     * @return int
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Setter function for id
     *
     * @param int $id
     */
    public function setId($id)
    {
        $this->id = $id;
    }

    /**
     * Getter function for assetName
     *
     * @return string
     */
    public function getAssetName()
    {
        return $this->assetName;
    }

    /**
     * Setter function for assetName
     *
     * @param string $assetName
     */
    public function setAssetName($assetName)
    {
        $this->assetName = $assetName;
    }

    /**
     * Getter function for assetPath
     *
     * @return string
     */
    public function getAssetPath()
    {
        return $this->assetPath;
    }

    /**
     * Setter function for assetPath
     *
     * @param string $assetPath
     */
    public function setAssetPath($assetPath)
    {
        $this->assetPath = $assetPath;
    }

    /**
     * Getter function for assetId
     *
     * @return int
     */
    public function getAssetId()
    {
        return $this->assetId;
    }

    /**
     * Getter function for userId
     *
     * @return int
     */
    public function getUserId()
    {
        return $this->userId;
    }

    /**
     * Getter function for action
     *
     * @return string
     */
    public function getAction()
    {
        return $this->action;
    }

    /**
     * Getter function for actionAt
     *
     * @return string
     */
    public function getActionAt()
    {
        return $this->actionAt;
    }

    /**
     * Setter function for assetId
     *
     * @param int $assetId
     */
    public function setAssetId($assetId)
    {
        $this->assetId = $assetId;
    }

    /**
     * Setter function for userId
     *
     * @param int $userId
     */
    public function setUserId($userId)
    {
        $this->userId = $userId;
    }

    /**
     * Setter function for action
     *
     * @param string $action
     */
    public function setAction($action)
    {
        $this->action = $action;
    }

    /**
     * Setter function for actionAt
     *
     * @param string $actionAt
     */
    public function setActionAt($actionAt)
    {
        $this->actionAt = $actionAt;
    }
}
