<?php
/**
 * Pimcore
 *
 * This source file is available under two different licenses:
 * - GNU General Public License version 3 (GPLv3)
 * - Pimcore Enterprise License (PEL)
 * Full copyright and license information is available in
 * LICENSE.md which is distributed with this source code.
 *
 * @package    AuditBundle
 *
 * @copyright  Copyright (c) Pimcore GmbH (http://www.pimcore.org)
 * @license    http://www.pimcore.org/license     GPLv3 and PEL
 */

namespace AuditBundle\Model\Asset\AssetAudit\Listing;

use Pimcore\Model;
use AuditBundle\Model\Asset\AssetAudit;

/**
 * @property \AuditBundle\Model\Asset\AssetAudit\Listing $model
 */
class Dao extends Model\Listing\Dao\AbstractDao
{
    /**
     * @var string
     */
    protected $tableName = 'asset_audit';

    /**
     * Loads a list of asset audits,
     * returns an array of audit records.
     *
     * @return array
     */
    public function load()
    {
        $auditData = $this->db->fetchCol(
            'SELECT id FROM ' . $this->tableName . $this->getCondition() . $this->getOrder() . $this->getOffsetLimit(),
            $this->model->getConditionVariables()
        );

        $auditRecords = [];
        foreach ($auditData as $record) {
            $auditRecords[] = AssetAudit::getById($record);
        }

        $this->model->setAssetAudits($auditRecords);

        return $auditRecords;
    }

    /**
     * Function to get the total records.
     *
     * @return int
     */
    public function getTotalCount()
    {
        $amount = 0;
        try {
            $amount = (int) $this->db->fetchOne(
                'SELECT COUNT(*) as amount FROM ' . $this->tableName . $this->getCondition(),
                $this->model->getConditionVariables()
            );
        } catch (\Exception $e) {
        }

        return $amount;
    }
}
